import random
class item():

    def __init__(self, demand: int, price: float, supply: int, popular: bool = None):
        self.demand = demand
        self.price = price
        self.supply = supply
        self.multiplier = self.price / self.demand
        self.isPopular = popular

    def progress(self, time: int, *, popular: bool = 0):
        x = None
        while time > 0:
            if popular == 0:
                if self.isPopular == True:
                    x = random.randint(self.demand + 10, self.demand + 30)
                elif self.isPopular == None:
                    x = random.randint(self.demand - 5, self.demand + 5)
                elif self.isPopular == False:
                    x = random.randint(self.demand - 30, self.demand - 10)
                else:
                    pass
            elif popular == True:
                x = random.randint(self.demand + 10, self.demand + 30)
            elif popular == None:
                x = random.randint(self.demand - 5, self.demand + 5)
            elif popular == False:
                x = random.randint(self.demand - 30, self.demand - 10)
            else:
                raise ("Error!")
            time -= 1
            if time <= 0:
                self.demand = x
                self.price = round(self.demand * self.multiplier, 2)
                self.supply -= self.demand
                if self.supply <= -1:
                    self. supply = 0


from PointSystem.Economy import item

class points():
    def __init__(self, tokenAmount: int, *,  classifier: str = None, front: bool = False):
        self.str = None
        self.points = tokenAmount
        if classifier == None:
            self.classifier = None
        else:
            if front == True:
                self.classifier = [classifier + ": ", ""]
            else:
                self.classifier = ["", " " + classifier]

    def add(self, add: int):
        self.points = self.points + add

    def sub(self, sub: int):
        self.points = self.points - sub

    def mult(self, mult: int):
        self.points = self.points * mult

    def div(self, div: int):
        self.points = self.points / div

    def set(self, amount: int = None):
        self.points = amount

    def round(self):
        self.points = int(self.points)

    def float(self):
        self.points = float(self.points)

    def reset(self):
        self.points = 0

    def setClassifier(self, classifier: str, front: bool):
        if front == True:
            self.classifier = [classifier + ": ", ""]
        else:
            self.classifier = ["", " " + classifier]

    def show(self):
        if self.classifier == None:
            print(self.points)
        else:
            print(str(self.points).join(self.classifier))

    def getStr(self):
        if self.classifier == None:
            self.str = str(self.points)
        else:
            self.str = str(str(self.points).join(self.classifier))

    def buy(self, BuyItem):
        if isinstance(BuyItem, item):
            if BuyItem.supply >= 1:
                self.sub(BuyItem.price)
        else:
            raise TypeError("Item is not a buyable item")


from src.PointSystem_Totallyahuman15.PointSystem import *

var = points(0, classifier="Coins", front=True) #You can put any number here, this is the amount the variable starts with
var.add(32)
var.div(3)
var.show()
var.round()
var.show()
var.float()
var.show()
var.mult(32)
var.getStr()
var2 = var.str
print(var2)
var.setClassifier(classifier="Points", front=False)
var.show()




from PointSystem.Points import points
from PointSystem.Economy import item

you = points(100, classifier="Coins", front=True)
potatoChips = item(price=3.54, demand=10, supply=30, popular=True)
print(potatoChips.price)
potatoChips.progress(time=10)
print(potatoChips.price)
print(potatoChips.supply)
you.show()
you.buy(potatoChips)
you.show()



from tkinter import *
from src.PointSystem_Totallyahuman15.PointSystem import *

root = Tk()
root.title("Example")
root.geometry("500x500")

p = points(0, classifier="Coins", front=True)

add = Button(root, text="Add 1 coin", command=lambda: p.add(1))
add.pack()

sub = Button(root, text="Subtract 1 coin", command=lambda: p.sub(1))
sub.pack()

mult = Button(root, text="Multiply by 3", command=lambda: p.mult(3))
mult.pack()

div = Button(root, text="Divide by 3", command=lambda: p.div(3))
div.pack()

def show():
    p.getStr()
    CoinLabel = Label(root, text=p.str)
    CoinLabel.pack()

show = Button(root, text="Show coin amount", command=show)
show.pack()

root.mainloop()